[
          {
            'number' => '1',
            'unicode' => 'E001',
            'name' => '男の子',
            'sjis' => '1b2447210f',
            'name_en' => 'Happy face',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image002.gif'
          },
          {
            'number' => '2',
            'unicode' => 'E002',
            'name' => '女の子',
            'sjis' => '1b2447220f',
            'name_en' => 'Happy face',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image004.gif'
          },
          {
            'number' => '3',
            'unicode' => 'E003',
            'name' => 'キスマーク',
            'sjis' => '1b2447230f',
            'name_en' => 'Kiss',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image006.gif'
          },
          {
            'number' => '4',
            'unicode' => 'E004',
            'name' => 'お父さん',
            'sjis' => '1b2447240f',
            'name_en' => 'Happy face',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image008.gif'
          },
          {
            'number' => '5',
            'unicode' => 'E005',
            'name' => 'お母さん',
            'sjis' => '1b2447250f',
            'name_en' => 'Happy face',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image010.gif'
          },
          {
            'number' => '6',
            'unicode' => 'E006',
            'name' => '洋服',
            'sjis' => '1b2447260f',
            'name_en' => 'T-shirt (border)',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image012.gif'
          },
          {
            'number' => '7',
            'unicode' => 'E007',
            'name' => 'ブーツ',
            'sjis' => '1b2447270f',
            'name_en' => 'Shoe',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image014.gif'
          },
          {
            'number' => '8',
            'unicode' => 'E008',
            'name' => 'カメラ',
            'sjis' => '1b2447280f',
            'name_en' => 'Camera',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image016.gif'
          },
          {
            'number' => '9',
            'unicode' => 'E009',
            'name' => '電話',
            'sjis' => '1b2447290f',
            'name_en' => 'Phone',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image018.gif'
          },
          {
            'number' => '10',
            'unicode' => 'E00A',
            'name' => '携帯電話',
            'sjis' => '1b24472a0f',
            'name_en' => 'Mobile phone',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image020.gif'
          },
          {
            'number' => '11',
            'unicode' => 'E00B',
            'name' => 'FAX',
            'sjis' => '1b24472b0f',
            'name_en' => 'fax to',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image022.gif'
          },
          {
            'number' => '12',
            'unicode' => 'E00C',
            'name' => 'パソコン',
            'sjis' => '1b24472c0f',
            'name_en' => 'Computer',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image024.gif'
          },
          {
            'number' => '13',
            'unicode' => 'E00D',
            'name' => 'パンチ',
            'sjis' => '1b24472d0f',
            'name_en' => 'Punch',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image026.gif'
          },
          {
            'number' => '14',
            'unicode' => 'E00E',
            'name' => 'GOOD!',
            'sjis' => '1b24472e0f',
            'name_en' => 'Thumbs up',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image028.gif'
          },
          {
            'number' => '15',
            'unicode' => 'E00F',
            'name' => 'No.1',
            'sjis' => '1b24472f0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image030.gif'
          },
          {
            'number' => '16',
            'unicode' => 'E010',
            'name' => 'グー',
            'sjis' => '1b2447300f',
            'name_en' => 'Hand (rock)',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image032.gif'
          },
          {
            'number' => '17',
            'unicode' => 'E011',
            'name' => 'チョキ',
            'sjis' => '1b2447310f',
            'name_en' => 'Hand (scissors)',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image034.gif'
          },
          {
            'number' => '18',
            'unicode' => 'E012',
            'name' => 'パー',
            'sjis' => '1b2447320f',
            'name_en' => 'Hand (paper)',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image036.gif'
          },
          {
            'number' => '19',
            'unicode' => 'E013',
            'name' => 'スキー',
            'sjis' => '1b2447330f',
            'name_en' => 'Ski',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image038.gif'
          },
          {
            'number' => '20',
            'unicode' => 'E014',
            'name' => 'ゴルフ',
            'sjis' => '1b2447340f',
            'name_en' => 'Golf',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image040.gif'
          },
          {
            'number' => '21',
            'unicode' => 'E015',
            'name' => 'テニス',
            'sjis' => '1b2447350f',
            'name_en' => 'Tennis',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image042.gif'
          },
          {
            'number' => '22',
            'unicode' => 'E016',
            'name' => '野球',
            'sjis' => '1b2447360f',
            'name_en' => 'Baseball',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image044.gif'
          },
          {
            'number' => '23',
            'unicode' => 'E017',
            'name' => 'サーフィン',
            'sjis' => '1b2447370f',
            'name_en' => 'Snowboarding',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image046.gif'
          },
          {
            'number' => '24',
            'unicode' => 'E018',
            'name' => 'サッカー',
            'sjis' => '1b2447380f',
            'name_en' => 'Soccer',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image048.gif'
          },
          {
            'number' => '25',
            'unicode' => 'E019',
            'name' => '魚',
            'sjis' => '1b2447390f',
            'name_en' => 'Fish',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image050.gif'
          },
          {
            'number' => '26',
            'unicode' => 'E01A',
            'name' => 'うま',
            'sjis' => '1b24473a0f',
            'name_en' => 'Horse',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image052.gif'
          },
          {
            'number' => '27',
            'unicode' => 'E01B',
            'name' => '車',
            'sjis' => '1b24473b0f',
            'name_en' => 'Car (sedan)',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image054.gif'
          },
          {
            'number' => '28',
            'unicode' => 'E01C',
            'name' => 'ヨット',
            'sjis' => '1b24473c0f',
            'name_en' => 'Resort',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image056.gif'
          },
          {
            'number' => '29',
            'unicode' => 'E01D',
            'name' => '飛行機',
            'sjis' => '1b24473d0f',
            'name_en' => 'Airplane',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image058.gif'
          },
          {
            'number' => '30',
            'unicode' => 'E01E',
            'name' => '電車',
            'sjis' => '1b24473e0f',
            'name_en' => 'Train',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image060.gif'
          },
          {
            'number' => '31',
            'unicode' => 'E01F',
            'name' => '新幹線',
            'sjis' => '1b24473f0f',
            'name_en' => 'Bullet train',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image062.gif'
          },
          {
            'number' => '32',
            'unicode' => 'E020',
            'name' => 'ハテナ',
            'sjis' => '1b2447400f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image064.gif'
          },
          {
            'number' => '33',
            'unicode' => 'E021',
            'name' => 'ビックリ',
            'sjis' => '1b2447410f',
            'name_en' => 'Exclamation mark',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image066.jpg'
          },
          {
            'number' => '34',
            'unicode' => 'E022',
            'name' => 'ハートマーク',
            'sjis' => '1b2447420f',
            'name_en' => 'Black heart',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image068.jpg'
          },
          {
            'number' => '35',
            'unicode' => 'E023',
            'name' => 'ハートブレイク',
            'sjis' => '1b2447430f',
            'name_en' => 'Heartbreak',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image070.jpg'
          },
          {
            'number' => '36',
            'unicode' => 'E024',
            'name' => '1時',
            'sjis' => '1b2447440f',
            'name_en' => 'Clock',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image072.gif'
          },
          {
            'number' => '37',
            'unicode' => 'E025',
            'name' => '2時',
            'sjis' => '1b2447450f',
            'name_en' => 'Clock',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image074.gif'
          },
          {
            'number' => '38',
            'unicode' => 'E026',
            'name' => '時計',
            'sjis' => '1b2447460f',
            'name_en' => 'Clock',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image076.gif'
          },
          {
            'number' => '39',
            'unicode' => 'E027',
            'name' => '4時',
            'sjis' => '1b2447470f',
            'name_en' => 'Clock',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image078.gif'
          },
          {
            'number' => '40',
            'unicode' => 'E028',
            'name' => '5時',
            'sjis' => '1b2447480f',
            'name_en' => 'Clock',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image080.gif'
          },
          {
            'number' => '41',
            'unicode' => 'E029',
            'name' => '6時',
            'sjis' => '1b2447490f',
            'name_en' => 'Clock',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image082.gif'
          },
          {
            'number' => '42',
            'unicode' => 'E02A',
            'name' => '7時',
            'sjis' => '1b24474a0f',
            'name_en' => 'Clock',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image084.gif'
          },
          {
            'number' => '43',
            'unicode' => 'E02B',
            'name' => '8時',
            'sjis' => '1b24474b0f',
            'name_en' => 'Clock',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image086.gif'
          },
          {
            'number' => '44',
            'unicode' => 'E02C',
            'name' => '9時',
            'sjis' => '1b24474c0f',
            'name_en' => 'Clock',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image088.gif'
          },
          {
            'number' => '45',
            'unicode' => 'E02D',
            'name' => '10時',
            'sjis' => '1b24474d0f',
            'name_en' => 'Clock',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image090.gif'
          },
          {
            'number' => '46',
            'unicode' => 'E02E',
            'name' => '11時',
            'sjis' => '1b24474e0f',
            'name_en' => 'Clock',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image092.gif'
          },
          {
            'number' => '47',
            'unicode' => 'E02F',
            'name' => '12時',
            'sjis' => '1b24474f0f',
            'name_en' => 'Clock',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image094.gif'
          },
          {
            'number' => '48',
            'unicode' => 'E030',
            'name' => 'お花見',
            'sjis' => '1b2447500f',
            'name_en' => 'Cherry blossom',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image096.jpg'
          },
          {
            'number' => '49',
            'unicode' => 'E031',
            'name' => 'エンブレム',
            'sjis' => '1b2447510f',
            'name_en' => 'Crown',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image098.jpg'
          },
          {
            'number' => '50',
            'unicode' => 'E032',
            'name' => 'バラ',
            'sjis' => '1b2447520f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image100.gif'
          },
          {
            'number' => '51',
            'unicode' => 'E033',
            'name' => 'クリスマス',
            'sjis' => '1b2447530f',
            'name_en' => 'Christmas',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image102.gif'
          },
          {
            'number' => '52',
            'unicode' => 'E034',
            'name' => '指輪',
            'sjis' => '1b2447540f',
            'name_en' => 'Ring',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image104.gif'
          },
          {
            'number' => '53',
            'unicode' => 'E035',
            'name' => '宝石',
            'sjis' => '1b2447550f',
            'name_en' => 'Ring',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image106.gif'
          },
          {
            'number' => '54',
            'unicode' => 'E036',
            'name' => '家',
            'sjis' => '1b2447560f',
            'name_en' => 'House',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image108.gif'
          },
          {
            'number' => '55',
            'unicode' => 'E037',
            'name' => '教会',
            'sjis' => '1b2447570f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image110.gif'
          },
          {
            'number' => '56',
            'unicode' => 'E038',
            'name' => 'ビル',
            'sjis' => '1b2447580f',
            'name_en' => 'Building',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image112.gif'
          },
          {
            'number' => '57',
            'unicode' => 'E039',
            'name' => '駅',
            'sjis' => '1b2447590f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image114.gif'
          },
          {
            'number' => '58',
            'unicode' => 'E03A',
            'name' => 'ガソリンスタンド',
            'sjis' => '1b24475a0f',
            'name_en' => 'Gas station',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image116.gif'
          },
          {
            'number' => '59',
            'unicode' => 'E03B',
            'name' => '山',
            'sjis' => '1b24475b0f',
            'name_en' => 'Mount Fuji',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image118.gif'
          },
          {
            'number' => '60',
            'unicode' => 'E03C',
            'name' => 'マイク',
            'sjis' => '1b24475c0f',
            'name_en' => 'Karaoke',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image120.gif'
          },
          {
            'number' => '61',
            'unicode' => 'E03D',
            'name' => '映画',
            'sjis' => '1b24475d0f',
            'name_en' => 'Movie',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image122.gif'
          },
          {
            'number' => '62',
            'unicode' => 'E03E',
            'name' => '音楽',
            'sjis' => '1b24475e0f',
            'name_en' => 'Cheerful',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image124.gif'
          },
          {
            'number' => '63',
            'unicode' => 'E03F',
            'name' => 'カギ',
            'sjis' => '1b24475f0f',
            'name_en' => 'Password',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image126.gif'
          },
          {
            'number' => '64',
            'unicode' => 'E040',
            'name' => 'サックス',
            'sjis' => '1b2447600f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image128.gif'
          },
          {
            'number' => '65',
            'unicode' => 'E041',
            'name' => 'ギター',
            'sjis' => '1b2447610f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image130.jpg'
          },
          {
            'number' => '66',
            'unicode' => 'E042',
            'name' => 'トランペット',
            'sjis' => '1b2447620f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image132.gif'
          },
          {
            'number' => '67',
            'unicode' => 'E043',
            'name' => 'レストラン',
            'sjis' => '1b2447630f',
            'name_en' => 'Restaurant',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image134.gif'
          },
          {
            'number' => '68',
            'unicode' => 'E044',
            'name' => 'カクテル',
            'sjis' => '1b2447640f',
            'name_en' => 'Bar',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image136.gif'
          },
          {
            'number' => '69',
            'unicode' => 'E045',
            'name' => 'コーヒー',
            'sjis' => '1b2447650f',
            'name_en' => 'CafÃ©',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image138.gif'
          },
          {
            'number' => '70',
            'unicode' => 'E046',
            'name' => 'ケーキ',
            'sjis' => '1b2447660f',
            'name_en' => 'Short cake',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image140.gif'
          },
          {
            'number' => '71',
            'unicode' => 'E047',
            'name' => 'ビール',
            'sjis' => '1b2447670f',
            'name_en' => 'Beer',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image142.gif'
          },
          {
            'number' => '72',
            'unicode' => 'E048',
            'name' => '雪',
            'sjis' => '1b2447680f',
            'name_en' => 'Snow',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image144.gif'
          },
          {
            'number' => '73',
            'unicode' => 'E049',
            'name' => '曇り',
            'sjis' => '1b2447690f',
            'name_en' => 'Cloudy',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image146.gif'
          },
          {
            'number' => '74',
            'unicode' => 'E04A',
            'name' => '晴れ(昼)',
            'sjis' => '1b24476a0f',
            'name_en' => 'Fine',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image148.gif'
          },
          {
            'number' => '75',
            'unicode' => 'E04B',
            'name' => '雨',
            'sjis' => '1b24476b0f',
            'name_en' => 'Rain',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image150.gif'
          },
          {
            'number' => '76',
            'unicode' => 'E04C',
            'name' => '晴れ(夜)',
            'sjis' => '1b24476c0f',
            'name_en' => 'Crescent moon',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image152.gif'
          },
          {
            'number' => '77',
            'unicode' => 'E04D',
            'name' => '朝',
            'sjis' => '1b24476d0f',
            'name_en' => 'Fine',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image154.gif'
          },
          {
            'number' => '78',
            'unicode' => 'E04E',
            'name' => '天使',
            'sjis' => '1b24476e0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image156.gif'
          },
          {
            'number' => '79',
            'unicode' => 'E04F',
            'name' => 'ねこ',
            'sjis' => '1b24476f0f',
            'name_en' => 'Cat',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image158.gif'
          },
          {
            'number' => '80',
            'unicode' => 'E050',
            'name' => 'とら',
            'sjis' => '1b2447700f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image160.gif'
          },
          {
            'number' => '81',
            'unicode' => 'E051',
            'name' => 'くま',
            'sjis' => '1b2447710f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image162.gif'
          },
          {
            'number' => '82',
            'unicode' => 'E052',
            'name' => 'いぬ',
            'sjis' => '1b2447720f',
            'name_en' => 'Dog',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image164.gif'
          },
          {
            'number' => '83',
            'unicode' => 'E053',
            'name' => 'ねずみ',
            'sjis' => '1b2447730f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image166.gif'
          },
          {
            'number' => '84',
            'unicode' => 'E054',
            'name' => 'クジラ',
            'sjis' => '1b2447740f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image168.gif'
          },
          {
            'number' => '85',
            'unicode' => 'E055',
            'name' => 'ペンギン',
            'sjis' => '1b2447750f',
            'name_en' => 'Penguin',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image170.gif'
          },
          {
            'number' => '86',
            'unicode' => 'E056',
            'name' => '楽',
            'sjis' => '1b2447760f',
            'name_en' => 'Happy face',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image172.gif'
          },
          {
            'number' => '87',
            'unicode' => 'E057',
            'name' => '喜',
            'sjis' => '1b2447770f',
            'name_en' => 'Happy face',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image174.gif'
          },
          {
            'number' => '88',
            'unicode' => 'E058',
            'name' => '哀',
            'sjis' => '1b2447780f',
            'name_en' => 'Disappointed face',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image176.gif'
          },
          {
            'number' => '89',
            'unicode' => 'E059',
            'name' => '怒',
            'sjis' => '1b2447790f',
            'name_en' => 'Angry face',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image178.gif'
          },
          {
            'number' => '90',
            'unicode' => 'E05A',
            'name' => 'ウンチ',
            'sjis' => '1b24477a0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/emoji_8271_image180.gif'
          },
          {
            'number' => '91',
            'unicode' => 'E101',
            'name' => 'メール受信',
            'sjis' => '1b2445210f',
            'name_en' => 'Post office',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-E21.gif'
          },
          {
            'number' => '92',
            'unicode' => 'E102',
            'name' => 'メール送信',
            'sjis' => '1b2445220f',
            'name_en' => 'Post office',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-E22.gif'
          },
          {
            'number' => '93',
            'unicode' => 'E103',
            'name' => 'メール宛先',
            'sjis' => '1b2445230f',
            'name_en' => 'mail to',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-E23.gif'
          },
          {
            'number' => '94',
            'unicode' => 'E104',
            'name' => '電話番号',
            'sjis' => '1b2445240f',
            'name_en' => 'Phone to',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-E24.gif'
          },
          {
            'number' => '95',
            'unicode' => 'E105',
            'name' => 'あっかんベー',
            'sjis' => '1b2445250f',
            'name_en' => 'Sticking tongue out',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-E25.gif'
          },
          {
            'number' => '96',
            'unicode' => 'E106',
            'name' => 'ラブラブ',
            'sjis' => '1b2445260f',
            'name_en' => 'Heart shaped eyes',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-E26.gif'
          },
          {
            'number' => '97',
            'unicode' => 'E107',
            'name' => 'ガビーン',
            'sjis' => '1b2445270f',
            'name_en' => 'Very thin',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-E27.gif'
          },
          {
            'number' => '98',
            'unicode' => 'E108',
            'name' => 'タラー',
            'sjis' => '1b2445280f',
            'name_en' => 'Cold sweat 2',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-E28.gif'
          },
          {
            'number' => '99',
            'unicode' => 'E109',
            'name' => 'さる',
            'sjis' => '1b2445290f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image016.gif'
          },
          {
            'number' => '100',
            'unicode' => 'E10A',
            'name' => 'たこ',
            'sjis' => '1b24452a0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image017.gif'
          },
          {
            'number' => '101',
            'unicode' => 'E10B',
            'name' => 'ぶた',
            'sjis' => '1b24452b0f',
            'name_en' => 'Pig',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image018.gif'
          },
          {
            'number' => '102',
            'unicode' => 'E10C',
            'name' => '宇宙人',
            'sjis' => '1b24452c0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image019.gif'
          },
          {
            'number' => '103',
            'unicode' => 'E10D',
            'name' => 'ロケット',
            'sjis' => '1b24452d0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-E2D.gif'
          },
          {
            'number' => '104',
            'unicode' => 'E10E',
            'name' => '王冠',
            'sjis' => '1b24452e0f',
            'name_en' => 'Crown',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image022.gif'
          },
          {
            'number' => '105',
            'unicode' => 'E10F',
            'name' => '電球',
            'sjis' => '1b24452f0f',
            'name_en' => 'Good idea',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-E2F.gif'
          },
          {
            'number' => '106',
            'unicode' => 'E110',
            'name' => 'よつば',
            'sjis' => '1b2445300f',
            'name_en' => '4-leaf clover',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image025.gif'
          },
          {
            'number' => '107',
            'unicode' => 'E111',
            'name' => 'キス',
            'sjis' => '1b2445310f',
            'name_en' => 'Kiss',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-E31.gif'
          },
          {
            'number' => '108',
            'unicode' => 'E112',
            'name' => 'バースデー',
            'sjis' => '1b2445320f',
            'name_en' => 'Present',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image029.gif'
          },
          {
            'number' => '109',
            'unicode' => 'E113',
            'name' => 'ピストル',
            'sjis' => '1b2445330f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-E33.gif'
          },
          {
            'number' => '110',
            'unicode' => 'E114',
            'name' => '虫眼鏡',
            'sjis' => '1b2445340f',
            'name_en' => 'Search',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image033.gif'
          },
          {
            'number' => '111',
            'unicode' => 'E115',
            'name' => '陸上',
            'sjis' => '1b2445350f',
            'name_en' => 'Running man',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-E35.gif'
          },
          {
            'number' => '112',
            'unicode' => 'E116',
            'name' => 'オークション',
            'sjis' => '1b2445360f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image037.gif'
          },
          {
            'number' => '113',
            'unicode' => 'E117',
            'name' => '花火',
            'sjis' => '1b2445370f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-E37.gif'
          },
          {
            'number' => '114',
            'unicode' => 'E118',
            'name' => 'もみじ',
            'sjis' => '1b2445380f',
            'name_en' => 'Maple leaf',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image041.gif'
          },
          {
            'number' => '115',
            'unicode' => 'E119',
            'name' => '落ち葉',
            'sjis' => '1b2445390f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-E39.gif'
          },
          {
            'number' => '116',
            'unicode' => 'E11A',
            'name' => '悪魔',
            'sjis' => '1b24453a0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image045.gif'
          },
          {
            'number' => '117',
            'unicode' => 'E11B',
            'name' => 'おばけ',
            'sjis' => '1b24453b0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-E3B.gif'
          },
          {
            'number' => '118',
            'unicode' => 'E11C',
            'name' => 'ドクロ',
            'sjis' => '1b24453c0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image049.gif'
          },
          {
            'number' => '119',
            'unicode' => 'E11D',
            'name' => 'ファイヤー',
            'sjis' => '1b24453d0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-E3D.gif'
          },
          {
            'number' => '120',
            'unicode' => 'E11E',
            'name' => 'かばん',
            'sjis' => '1b24453e0f',
            'name_en' => 'Bag',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image053.gif'
          },
          {
            'number' => '121',
            'unicode' => 'E11F',
            'name' => '座席',
            'sjis' => '1b24453f0f',
            'name_en' => 'Chair',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image055.gif'
          },
          {
            'number' => '122',
            'unicode' => 'E120',
            'name' => 'ハンバーガ',
            'sjis' => '1b2445400f',
            'name_en' => 'Fast food',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image056.gif'
          },
          {
            'number' => '123',
            'unicode' => 'E121',
            'name' => '公園',
            'sjis' => '1b2445410f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image057.gif'
          },
          {
            'number' => '124',
            'unicode' => 'E122',
            'name' => 'キャンプ場',
            'sjis' => '1b2445420f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image058.gif'
          },
          {
            'number' => '125',
            'unicode' => 'E123',
            'name' => '温泉',
            'sjis' => '1b2445430f',
            'name_en' => 'Comfort (hot spring)',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image059.gif'
          },
          {
            'number' => '126',
            'unicode' => 'E124',
            'name' => '遊園地',
            'sjis' => '1b2445440f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image060.gif'
          },
          {
            'number' => '127',
            'unicode' => 'E125',
            'name' => 'チケット',
            'sjis' => '1b2445450f',
            'name_en' => 'Ticket',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image061.gif'
          },
          {
            'number' => '128',
            'unicode' => 'E126',
            'name' => 'CD',
            'sjis' => '1b2445460f',
            'name_en' => 'CD',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image062.gif'
          },
          {
            'number' => '129',
            'unicode' => 'E127',
            'name' => 'DVD',
            'sjis' => '1b2445470f',
            'name_en' => 'CD',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image063.gif'
          },
          {
            'number' => '130',
            'unicode' => 'E128',
            'name' => 'ラジオ',
            'sjis' => '1b2445480f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image064.gif'
          },
          {
            'number' => '131',
            'unicode' => 'E129',
            'name' => 'ビデオ',
            'sjis' => '1b2445490f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image065.gif'
          },
          {
            'number' => '132',
            'unicode' => 'E12A',
            'name' => 'テレビ',
            'sjis' => '1b24454a0f',
            'name_en' => 'TV',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image066.gif'
          },
          {
            'number' => '133',
            'unicode' => 'E12B',
            'name' => 'ゲーム',
            'sjis' => '1b24454b0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-E4B.gif'
          },
          {
            'number' => '134',
            'unicode' => 'E12C',
            'name' => '歌い出し',
            'sjis' => '1b24454c0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image068.gif'
          },
          {
            'number' => '135',
            'unicode' => 'E12D',
            'name' => 'マージャン',
            'sjis' => '1b24454d0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image069.gif'
          },
          {
            'number' => '136',
            'unicode' => 'E12E',
            'name' => '対決',
            'sjis' => '1b24454e0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-E4E.gif'
          },
          {
            'number' => '137',
            'unicode' => 'E12F',
            'name' => '賞金',
            'sjis' => '1b24454f0f',
            'name_en' => 'Money bag',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image071.gif'
          },
          {
            'number' => '138',
            'unicode' => 'E130',
            'name' => '当り',
            'sjis' => '1b2445500f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-E50.gif'
          },
          {
            'number' => '139',
            'unicode' => 'E131',
            'name' => 'トロフィー',
            'sjis' => '1b2445510f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image074.gif'
          },
          {
            'number' => '140',
            'unicode' => 'E132',
            'name' => 'ゴール',
            'sjis' => '1b2445520f',
            'name_en' => 'Motor sports',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image075.gif'
          },
          {
            'number' => '141',
            'unicode' => 'E133',
            'name' => 'スロット',
            'sjis' => '1b2445530f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image076.gif'
          },
          {
            'number' => '142',
            'unicode' => 'E134',
            'name' => '競馬',
            'sjis' => '1b2445540f',
            'name_en' => 'Horse',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image077.gif'
          },
          {
            'number' => '143',
            'unicode' => 'E135',
            'name' => '競艇',
            'sjis' => '1b2445550f',
            'name_en' => 'Resort',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image078.gif'
          },
          {
            'number' => '144',
            'unicode' => 'E136',
            'name' => '競輪',
            'sjis' => '1b2445560f',
            'name_en' => 'Bicycle',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image079.gif'
          },
          {
            'number' => '145',
            'unicode' => 'E137',
            'name' => '工事中',
            'sjis' => '1b2445570f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image080.gif'
          },
          {
            'number' => '146',
            'unicode' => 'E138',
            'name' => '男性',
            'sjis' => '1b2445580f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image081.gif'
          },
          {
            'number' => '147',
            'unicode' => 'E139',
            'name' => '女性',
            'sjis' => '1b2445590f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image082.gif'
          },
          {
            'number' => '148',
            'unicode' => 'E13A',
            'name' => '乳幼児',
            'sjis' => '1b24455a0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image083.gif'
          },
          {
            'number' => '149',
            'unicode' => 'E13B',
            'name' => '注射器',
            'sjis' => '1b24455b0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image084.gif'
          },
          {
            'number' => '150',
            'unicode' => 'E13C',
            'name' => '睡眠',
            'sjis' => '1b24455c0f',
            'name_en' => 'Sleepy (sleep)',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image085.gif'
          },
          {
            'number' => '151',
            'unicode' => 'E13D',
            'name' => '雷',
            'sjis' => '1b24455d0f',
            'name_en' => 'Thunder',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image086.gif'
          },
          {
            'number' => '152',
            'unicode' => 'E13E',
            'name' => 'ハイヒール',
            'sjis' => '1b24455e0f',
            'name_en' => 'Boutique',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image087.gif'
          },
          {
            'number' => '153',
            'unicode' => 'E13F',
            'name' => '入浴',
            'sjis' => '1b24455f0f',
            'name_en' => 'Comfort (hot spring)',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image088.gif'
          },
          {
            'number' => '154',
            'unicode' => 'E140',
            'name' => 'トイレ',
            'sjis' => '1b2445600f',
            'name_en' => 'Toilet',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image089.gif'
          },
          {
            'number' => '155',
            'unicode' => 'E141',
            'name' => '音声',
            'sjis' => '1b2445610f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image090.gif'
          },
          {
            'number' => '156',
            'unicode' => 'E142',
            'name' => 'お知らせ',
            'sjis' => '1b2445620f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image091.gif'
          },
          {
            'number' => '157',
            'unicode' => 'E143',
            'name' => '祝日',
            'sjis' => '1b2445630f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image092.gif'
          },
          {
            'number' => '158',
            'unicode' => 'E144',
            'name' => 'ロックON',
            'sjis' => '1b2445640f',
            'name_en' => 'Password',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image093.gif'
          },
          {
            'number' => '159',
            'unicode' => 'E145',
            'name' => 'ロックOFF',
            'sjis' => '1b2445650f',
            'name_en' => 'Password',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image094.gif'
          },
          {
            'number' => '160',
            'unicode' => 'E146',
            'name' => '街',
            'sjis' => '1b2445660f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image095.gif'
          },
          {
            'number' => '161',
            'unicode' => 'E147',
            'name' => '料理',
            'sjis' => '1b2445670f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image096.gif'
          },
          {
            'number' => '162',
            'unicode' => 'E148',
            'name' => '本',
            'sjis' => '1b2445680f',
            'name_en' => 'Book',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image097.gif'
          },
          {
            'number' => '163',
            'unicode' => 'E149',
            'name' => '為替相場',
            'sjis' => '1b2445690f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image098.gif'
          },
          {
            'number' => '164',
            'unicode' => 'E14A',
            'name' => '株価',
            'sjis' => '1b24456a0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image099.gif'
          },
          {
            'number' => '165',
            'unicode' => 'E14B',
            'name' => 'ニュース',
            'sjis' => '1b24456b0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image100.gif'
          },
          {
            'number' => '166',
            'unicode' => 'E14C',
            'name' => '元気',
            'sjis' => '1b24456c0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image101.gif'
          },
          {
            'number' => '167',
            'unicode' => 'E14D',
            'name' => '銀行',
            'sjis' => '1b24456d0f',
            'name_en' => 'Bank',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image102.gif'
          },
          {
            'number' => '168',
            'unicode' => 'E14E',
            'name' => '信号',
            'sjis' => '1b24456e0f',
            'name_en' => 'Traffic signal',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image103.gif'
          },
          {
            'number' => '169',
            'unicode' => 'E14F',
            'name' => '駐車場',
            'sjis' => '1b24456f0f',
            'name_en' => 'Parking',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image104.gif'
          },
          {
            'number' => '170',
            'unicode' => 'E150',
            'name' => 'バス停',
            'sjis' => '1b2445700f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image105.gif'
          },
          {
            'number' => '171',
            'unicode' => 'E151',
            'name' => '公衆トイレ',
            'sjis' => '1b2445710f',
            'name_en' => 'Toilet',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image106.gif'
          },
          {
            'number' => '172',
            'unicode' => 'E152',
            'name' => '交番',
            'sjis' => '1b2445720f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image107.gif'
          },
          {
            'number' => '173',
            'unicode' => 'E153',
            'name' => '郵便局',
            'sjis' => '1b2445730f',
            'name_en' => 'Post office',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image108.gif'
          },
          {
            'number' => '174',
            'unicode' => 'E154',
            'name' => 'ATM',
            'sjis' => '1b2445740f',
            'name_en' => 'ATM',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image109.gif'
          },
          {
            'number' => '175',
            'unicode' => 'E155',
            'name' => '病院',
            'sjis' => '1b2445750f',
            'name_en' => 'Hospital',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image110.gif'
          },
          {
            'number' => '176',
            'unicode' => 'E156',
            'name' => 'コンビニ',
            'sjis' => '1b2445760f',
            'name_en' => 'Convenience store',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image111.gif'
          },
          {
            'number' => '177',
            'unicode' => 'E157',
            'name' => '学校',
            'sjis' => '1b2445770f',
            'name_en' => 'School',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image112.gif'
          },
          {
            'number' => '178',
            'unicode' => 'E158',
            'name' => 'ホテル',
            'sjis' => '1b2445780f',
            'name_en' => 'Hotel',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image113.gif'
          },
          {
            'number' => '179',
            'unicode' => 'E159',
            'name' => 'バス',
            'sjis' => '1b2445790f',
            'name_en' => 'Bus',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image114.gif'
          },
          {
            'number' => '180',
            'unicode' => 'E15A',
            'name' => 'タクシー',
            'sjis' => '1b24457a0f',
            'name_en' => 'Car (sedan)',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_8285_image116.gif'
          },
          {
            'number' => '181',
            'unicode' => 'E201',
            'name' => '徒歩',
            'sjis' => '1b2446210f',
            'name_en' => 'Running man',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-F21.gif'
          },
          {
            'number' => '182',
            'unicode' => 'E202',
            'name' => '船',
            'sjis' => '1b2446220f',
            'name_en' => 'Ship',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image002.gif'
          },
          {
            'number' => '183',
            'unicode' => 'E203',
            'name' => '目的地',
            'sjis' => '1b2446230f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-F23.gif'
          },
          {
            'number' => '184',
            'unicode' => 'E204',
            'name' => '飾罫1',
            'sjis' => '1b2446240f',
            'name_en' => 'Cute',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image004.gif'
          },
          {
            'number' => '185',
            'unicode' => 'E205',
            'name' => '飾罫2',
            'sjis' => '1b2446250f',
            'name_en' => 'Cute',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image005.gif'
          },
          {
            'number' => '186',
            'unicode' => 'E206',
            'name' => '飾罫3',
            'sjis' => '1b2446260f',
            'name_en' => 'Cute',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-F26.gif'
          },
          {
            'number' => '187',
            'unicode' => 'E207',
            'name' => '18禁',
            'sjis' => '1b2446270f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image007.gif'
          },
          {
            'number' => '188',
            'unicode' => 'E208',
            'name' => '禁煙',
            'sjis' => '1b2446280f',
            'name_en' => 'Non-smoking',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image008.gif'
          },
          {
            'number' => '189',
            'unicode' => 'E209',
            'name' => '初心者',
            'sjis' => '1b2446290f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image009.gif'
          },
          {
            'number' => '190',
            'unicode' => 'E20A',
            'name' => 'バリアフリー',
            'sjis' => '1b24462a0f',
            'name_en' => 'Wheelchair',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image010.gif'
          },
          {
            'number' => '191',
            'unicode' => 'E20B',
            'name' => 'アンテナマーク',
            'sjis' => '1b24462b0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image011.gif'
          },
          {
            'number' => '192',
            'unicode' => 'E20C',
            'name' => 'ハート',
            'sjis' => '1b24462c0f',
            'name_en' => 'Heart',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image012.gif'
          },
          {
            'number' => '193',
            'unicode' => 'E20D',
            'name' => 'ダイヤ',
            'sjis' => '1b24462d0f',
            'name_en' => 'Diamond',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image013.gif'
          },
          {
            'number' => '194',
            'unicode' => 'E20E',
            'name' => 'スペード',
            'sjis' => '1b24462e0f',
            'name_en' => 'Spade',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image014.gif'
          },
          {
            'number' => '195',
            'unicode' => 'E20F',
            'name' => 'クラブ',
            'sjis' => '1b24462f0f',
            'name_en' => 'Club',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image015.gif'
          },
          {
            'number' => '196',
            'unicode' => 'E210',
            'name' => 'シャープダイヤル',
            'sjis' => '1b2446300f',
            'name_en' => 'Sharp dial',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image016.gif'
          },
          {
            'number' => '197',
            'unicode' => 'E211',
            'name' => 'フリーダイヤル',
            'sjis' => '1b2446310f',
            'name_en' => 'Free dial',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image017.gif'
          },
          {
            'number' => '198',
            'unicode' => 'E212',
            'name' => '新着',
            'sjis' => '1b2446320f',
            'name_en' => 'New',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image018.gif'
          },
          {
            'number' => '199',
            'unicode' => 'E213',
            'name' => '更新',
            'sjis' => '1b2446330f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image019.gif'
          },
          {
            'number' => '200',
            'unicode' => 'E214',
            'name' => 'おすすめ',
            'sjis' => '1b2446340f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image020.gif'
          },
          {
            'number' => '201',
            'unicode' => 'E215',
            'name' => '有料',
            'sjis' => '1b2446350f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image021.gif'
          },
          {
            'number' => '202',
            'unicode' => 'E216',
            'name' => '無料',
            'sjis' => '1b2446360f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image022.gif'
          },
          {
            'number' => '203',
            'unicode' => 'E217',
            'name' => '月額',
            'sjis' => '1b2446370f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image023.gif'
          },
          {
            'number' => '204',
            'unicode' => 'E218',
            'name' => '申し込み',
            'sjis' => '1b2446380f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image024.gif'
          },
          {
            'number' => '205',
            'unicode' => 'E219',
            'name' => '見出しボタン1',
            'sjis' => '1b2446390f',
            'name_en' => 'New moon',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-F39.gif'
          },
          {
            'number' => '206',
            'unicode' => 'E21A',
            'name' => '見出しボタン2',
            'sjis' => '1b24463a0f',
            'name_en' => 'New moon',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image027.gif'
          },
          {
            'number' => '207',
            'unicode' => 'E21B',
            'name' => '見出しボタン3',
            'sjis' => '1b24463b0f',
            'name_en' => 'New moon',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image028.gif'
          },
          {
            'number' => '208',
            'unicode' => 'E21C',
            'name' => '1ボタン',
            'sjis' => '1b24463c0f',
            'name_en' => '1',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image029.gif'
          },
          {
            'number' => '209',
            'unicode' => 'E21D',
            'name' => '2ボタン',
            'sjis' => '1b24463d0f',
            'name_en' => '2',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image030.gif'
          },
          {
            'number' => '210',
            'unicode' => 'E21E',
            'name' => '3ボタン',
            'sjis' => '1b24463e0f',
            'name_en' => '3',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image031.gif'
          },
          {
            'number' => '211',
            'unicode' => 'E21F',
            'name' => '4ボタン',
            'sjis' => '1b24463f0f',
            'name_en' => '4',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image032.gif'
          },
          {
            'number' => '212',
            'unicode' => 'E220',
            'name' => '5ボタン',
            'sjis' => '1b2446400f',
            'name_en' => '5',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image033.gif'
          },
          {
            'number' => '213',
            'unicode' => 'E221',
            'name' => '6ボタン',
            'sjis' => '1b2446410f',
            'name_en' => '6',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image034.gif'
          },
          {
            'number' => '214',
            'unicode' => 'E222',
            'name' => '7ボタン',
            'sjis' => '1b2446420f',
            'name_en' => '7',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image035.gif'
          },
          {
            'number' => '215',
            'unicode' => 'E223',
            'name' => '8ボタン',
            'sjis' => '1b2446430f',
            'name_en' => '8',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image036.gif'
          },
          {
            'number' => '216',
            'unicode' => 'E224',
            'name' => '9ボタン',
            'sjis' => '1b2446440f',
            'name_en' => '9',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image037.gif'
          },
          {
            'number' => '217',
            'unicode' => 'E225',
            'name' => '0ボタン',
            'sjis' => '1b2446450f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image038.gif'
          },
          {
            'number' => '218',
            'unicode' => 'E226',
            'name' => 'お得',
            'sjis' => '1b2446460f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image039.gif'
          },
          {
            'number' => '219',
            'unicode' => 'E227',
            'name' => '割引',
            'sjis' => '1b2446470f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image040.gif'
          },
          {
            'number' => '220',
            'unicode' => 'E228',
            'name' => 'サービス料',
            'sjis' => '1b2446480f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image041.gif'
          },
          {
            'number' => '221',
            'unicode' => 'E229',
            'name' => 'ID',
            'sjis' => '1b2446490f',
            'name_en' => 'ID',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image042.gif'
          },
          {
            'number' => '222',
            'unicode' => 'E22A',
            'name' => '満席',
            'sjis' => '1b24464a0f',
            'name_en' => 'Full',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image043.gif'
          },
          {
            'number' => '223',
            'unicode' => 'E22B',
            'name' => '空席',
            'sjis' => '1b24464b0f',
            'name_en' => 'Vacant',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image044.gif'
          },
          {
            'number' => '224',
            'unicode' => 'E22C',
            'name' => '指定席',
            'sjis' => '1b24464c0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image045.gif'
          },
          {
            'number' => '225',
            'unicode' => 'E22D',
            'name' => '営業時間',
            'sjis' => '1b24464d0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image046.gif'
          },
          {
            'number' => '226',
            'unicode' => 'E22E',
            'name' => '上へ',
            'sjis' => '1b24464e0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image047.gif'
          },
          {
            'number' => '227',
            'unicode' => 'E22F',
            'name' => '下へ',
            'sjis' => '1b24464f0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image048.gif'
          },
          {
            'number' => '228',
            'unicode' => 'E230',
            'name' => '左へ',
            'sjis' => '1b2446500f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image049.gif'
          },
          {
            'number' => '229',
            'unicode' => 'E231',
            'name' => '右へ',
            'sjis' => '1b2446510f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image050.gif'
          },
          {
            'number' => '230',
            'unicode' => 'E232',
            'name' => '上',
            'sjis' => '1b2446520f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image051.gif'
          },
          {
            'number' => '231',
            'unicode' => 'E233',
            'name' => '下',
            'sjis' => '1b2446530f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image052.gif'
          },
          {
            'number' => '232',
            'unicode' => 'E234',
            'name' => '右',
            'sjis' => '1b2446540f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image053.gif'
          },
          {
            'number' => '233',
            'unicode' => 'E235',
            'name' => '左',
            'sjis' => '1b2446550f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image054.gif'
          },
          {
            'number' => '234',
            'unicode' => 'E236',
            'name' => '右上',
            'sjis' => '1b2446560f',
            'name_en' => 'Diagonally upward toward right',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image055.gif'
          },
          {
            'number' => '235',
            'unicode' => 'E237',
            'name' => '左上',
            'sjis' => '1b2446570f',
            'name_en' => 'Diagonally upward toward left',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image056.gif'
          },
          {
            'number' => '236',
            'unicode' => 'E238',
            'name' => '右下',
            'sjis' => '1b2446580f',
            'name_en' => 'Diagonally downward toward right',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image057.gif'
          },
          {
            'number' => '237',
            'unicode' => 'E239',
            'name' => '左下',
            'sjis' => '1b2446590f',
            'name_en' => 'Diagonally downward toward left',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image058.gif'
          },
          {
            'number' => '238',
            'unicode' => 'E23A',
            'name' => '次へ',
            'sjis' => '1b24465a0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image059.gif'
          },
          {
            'number' => '239',
            'unicode' => 'E23B',
            'name' => '前へ',
            'sjis' => '1b24465b0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image060.gif'
          },
          {
            'number' => '240',
            'unicode' => 'E23C',
            'name' => '早送り',
            'sjis' => '1b24465c0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image061.gif'
          },
          {
            'number' => '241',
            'unicode' => 'E23D',
            'name' => '巻戻し',
            'sjis' => '1b24465d0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image062.gif'
          },
          {
            'number' => '242',
            'unicode' => 'E23E',
            'name' => '星座',
            'sjis' => '1b24465e0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image063.gif'
          },
          {
            'number' => '243',
            'unicode' => 'E23F',
            'name' => 'おひつじ座',
            'sjis' => '1b24465f0f',
            'name_en' => 'Aries',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image064.gif'
          },
          {
            'number' => '244',
            'unicode' => 'E240',
            'name' => 'おうし座',
            'sjis' => '1b2446600f',
            'name_en' => 'Taurus',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image065.gif'
          },
          {
            'number' => '245',
            'unicode' => 'E241',
            'name' => 'ふたご座',
            'sjis' => '1b2446610f',
            'name_en' => 'Gemini',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image066.gif'
          },
          {
            'number' => '246',
            'unicode' => 'E242',
            'name' => 'かに座',
            'sjis' => '1b2446620f',
            'name_en' => 'Cancer',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image067.gif'
          },
          {
            'number' => '247',
            'unicode' => 'E243',
            'name' => 'しし座',
            'sjis' => '1b2446630f',
            'name_en' => 'Leo',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image068.gif'
          },
          {
            'number' => '248',
            'unicode' => 'E244',
            'name' => 'おとめ座',
            'sjis' => '1b2446640f',
            'name_en' => 'Virgo',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image069.gif'
          },
          {
            'number' => '249',
            'unicode' => 'E245',
            'name' => 'てんびん座',
            'sjis' => '1b2446650f',
            'name_en' => 'Libra',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image070.gif'
          },
          {
            'number' => '250',
            'unicode' => 'E246',
            'name' => 'さそり座',
            'sjis' => '1b2446660f',
            'name_en' => 'Scorpio',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image071.gif'
          },
          {
            'number' => '251',
            'unicode' => 'E247',
            'name' => 'いて座',
            'sjis' => '1b2446670f',
            'name_en' => 'Sagittarius',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image072.gif'
          },
          {
            'number' => '252',
            'unicode' => 'E248',
            'name' => 'やぎ座',
            'sjis' => '1b2446680f',
            'name_en' => 'Capricorn',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image073.gif'
          },
          {
            'number' => '253',
            'unicode' => 'E249',
            'name' => 'みずがめ座',
            'sjis' => '1b2446690f',
            'name_en' => 'Aquarius',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image074.gif'
          },
          {
            'number' => '254',
            'unicode' => 'E24A',
            'name' => 'うお座',
            'sjis' => '1b24466a0f',
            'name_en' => 'Pisces',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image075.gif'
          },
          {
            'number' => '255',
            'unicode' => 'E24B',
            'name' => 'へびつかい座',
            'sjis' => '1b24466b0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image076.gif'
          },
          {
            'number' => '256',
            'unicode' => 'E24C',
            'name' => 'TOPページ',
            'sjis' => '1b24466c0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image077.gif'
          },
          {
            'number' => '257',
            'unicode' => 'E24D',
            'name' => 'OKボタン',
            'sjis' => '1b24466d0f',
            'name_en' => 'Accept',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image078.gif'
          },
          {
            'number' => '258',
            'unicode' => 'E24E',
            'name' => '著作権',
            'sjis' => '1b24466e0f',
            'name_en' => 'Copyright',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image079.gif'
          },
          {
            'number' => '259',
            'unicode' => 'E24F',
            'name' => '登録商標',
            'sjis' => '1b24466f0f',
            'name_en' => 'Registered trademark',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image080.gif'
          },
          {
            'number' => '260',
            'unicode' => 'E250',
            'name' => 'マナーモード',
            'sjis' => '1b2446700f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image081.gif'
          },
          {
            'number' => '261',
            'unicode' => 'E251',
            'name' => '電源切',
            'sjis' => '1b2446710f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image082.gif'
          },
          {
            'number' => '262',
            'unicode' => 'E252',
            'name' => 'ご注意',
            'sjis' => '1b2446720f',
            'name_en' => 'Danger / Caution',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image083.gif'
          },
          {
            'number' => '263',
            'unicode' => 'E253',
            'name' => 'ご案内',
            'sjis' => '1b2446730f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_20251_image084.gif'
          },
          {
            'number' => '264',
            'unicode' => 'E255',
            'name' => 'スカイウェイブ',
            'sjis' => '1b2446750f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-F75.gif'
          },
          {
            'number' => '265',
            'unicode' => 'E256',
            'name' => 'スカイウォーカー',
            'sjis' => '1b2446760f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-F76.gif'
          },
          {
            'number' => '266',
            'unicode' => 'E257',
            'name' => 'スカイメロディ',
            'sjis' => '1b2446770f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c15-F77.gif'
          },
          {
            'number' => '271',
            'unicode' => 'E301',
            'name' => 'メモ',
            'sjis' => '1b244f210f',
            'name_en' => 'Memo',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image002.gif'
          },
          {
            'number' => '272',
            'unicode' => 'E302',
            'name' => 'ネクタイ',
            'sjis' => '1b244f220f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image004.gif'
          },
          {
            'number' => '273',
            'unicode' => 'E303',
            'name' => 'ハイビスカス',
            'sjis' => '1b244f230f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image006.gif'
          },
          {
            'number' => '274',
            'unicode' => 'E304',
            'name' => 'チューリップ',
            'sjis' => '1b244f240f',
            'name_en' => 'Tulip',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image008.gif'
          },
          {
            'number' => '275',
            'unicode' => 'E305',
            'name' => 'ひまわり',
            'sjis' => '1b244f250f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image010.gif'
          },
          {
            'number' => '276',
            'unicode' => 'E306',
            'name' => '花束',
            'sjis' => '1b244f260f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image012.gif'
          },
          {
            'number' => '277',
            'unicode' => 'E307',
            'name' => 'やしの木',
            'sjis' => '1b244f270f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image014.gif'
          },
          {
            'number' => '278',
            'unicode' => 'E308',
            'name' => 'サボテン',
            'sjis' => '1b244f280f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image016.gif'
          },
          {
            'number' => '279',
            'unicode' => 'E309',
            'name' => 'トイレ',
            'sjis' => '1b244f290f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image018.gif'
          },
          {
            'number' => '280',
            'unicode' => 'E30A',
            'name' => 'ヘッドフォン',
            'sjis' => '1b244f2a0f',
            'name_en' => 'Music',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image020.gif'
          },
          {
            'number' => '281',
            'unicode' => 'E30B',
            'name' => '晩酌',
            'sjis' => '1b244f2b0f',
            'name_en' => 'Sake bottle (sake cup)',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image022.gif'
          },
          {
            'number' => '282',
            'unicode' => 'E30C',
            'name' => '乾杯',
            'sjis' => '1b244f2c0f',
            'name_en' => 'Beer',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/a12.gif'
          },
          {
            'number' => '283',
            'unicode' => 'E30D',
            'name' => '祝',
            'sjis' => '1b244f2d0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image026.gif'
          },
          {
            'number' => '284',
            'unicode' => 'E30E',
            'name' => '喫煙',
            'sjis' => '1b244f2e0f',
            'name_en' => 'Smoking',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image028.gif'
          },
          {
            'number' => '285',
            'unicode' => 'E30F',
            'name' => 'カプセル薬',
            'sjis' => '1b244f2f0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image030.gif'
          },
          {
            'number' => '286',
            'unicode' => 'E310',
            'name' => '風船',
            'sjis' => '1b244f300f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/a16.gif'
          },
          {
            'number' => '287',
            'unicode' => 'E311',
            'name' => '爆弾',
            'sjis' => '1b244f310f',
            'name_en' => 'Bomb',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/a17.gif'
          },
          {
            'number' => '288',
            'unicode' => 'E312',
            'name' => 'クラッカー',
            'sjis' => '1b244f320f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/a18.gif'
          },
          {
            'number' => '289',
            'unicode' => 'E313',
            'name' => 'ハサミ',
            'sjis' => '1b244f330f',
            'name_en' => 'Hairdresser',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/a19.gif'
          },
          {
            'number' => '290',
            'unicode' => 'E314',
            'name' => 'リボン',
            'sjis' => '1b244f340f',
            'name_en' => 'Ribbon',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image040.gif'
          },
          {
            'number' => '291',
            'unicode' => 'E315',
            'name' => 'マル秘',
            'sjis' => '1b244f350f',
            'name_en' => 'Top secret',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image042.gif'
          },
          {
            'number' => '292',
            'unicode' => 'E316',
            'name' => 'MD',
            'sjis' => '1b244f360f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image044.gif'
          },
          {
            'number' => '293',
            'unicode' => 'E317',
            'name' => 'メガフォン',
            'sjis' => '1b244f370f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/a23.gif'
          },
          {
            'number' => '294',
            'unicode' => 'E318',
            'name' => '帽子',
            'sjis' => '1b244f380f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image048.gif'
          },
          {
            'number' => '295',
            'unicode' => 'E319',
            'name' => '可愛いワンピース',
            'sjis' => '1b244f390f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image050.gif'
          },
          {
            'number' => '296',
            'unicode' => 'E31A',
            'name' => 'ミュール',
            'sjis' => '1b244f3a0f',
            'name_en' => 'Boutique',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image052.gif'
          },
          {
            'number' => '297',
            'unicode' => 'E31B',
            'name' => 'ロングブーツ',
            'sjis' => '1b244f3b0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image054.gif'
          },
          {
            'number' => '298',
            'unicode' => 'E31C',
            'name' => '口紅',
            'sjis' => '1b244f3c0f',
            'name_en' => 'Make-up',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image056.gif'
          },
          {
            'number' => '299',
            'unicode' => 'E31D',
            'name' => 'マニュキア',
            'sjis' => '1b244f3d0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image058.gif'
          },
          {
            'number' => '300',
            'unicode' => 'E31E',
            'name' => 'エステ',
            'sjis' => '1b244f3e0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/a30.gif'
          },
          {
            'number' => '301',
            'unicode' => 'E31F',
            'name' => '美容院',
            'sjis' => '1b244f3f0f',
            'name_en' => 'Hairdresser',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/a31.gif'
          },
          {
            'number' => '302',
            'unicode' => 'E320',
            'name' => '理容院',
            'sjis' => '1b244f400f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/a32.gif'
          },
          {
            'number' => '303',
            'unicode' => 'E321',
            'name' => '着物',
            'sjis' => '1b244f410f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image066.gif'
          },
          {
            'number' => '304',
            'unicode' => 'E322',
            'name' => 'ビキニ',
            'sjis' => '1b244f420f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image068.gif'
          },
          {
            'number' => '305',
            'unicode' => 'E323',
            'name' => 'ブランドバック',
            'sjis' => '1b244f430f',
            'name_en' => 'Bag',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image070.gif'
          },
          {
            'number' => '306',
            'unicode' => 'E324',
            'name' => 'カチンコ',
            'sjis' => '1b244f440f',
            'name_en' => 'Clapboard',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image072.gif'
          },
          {
            'number' => '307',
            'unicode' => 'E325',
            'name' => 'すず',
            'sjis' => '1b244f450f',
            'name_en' => 'Chapel',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/a37.gif'
          },
          {
            'number' => '308',
            'unicode' => 'E326',
            'name' => '踊る音符',
            'sjis' => '1b244f460f',
            'name_en' => 'Mood',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/a38.gif'
          },
          {
            'number' => '309',
            'unicode' => 'E327',
            'name' => 'ぴかぴかハート',
            'sjis' => '1b244f470f',
            'name_en' => 'Black heart',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/a39.gif'
          },
          {
            'number' => '310',
            'unicode' => 'E328',
            'name' => 'どきどきハート',
            'sjis' => '1b244f480f',
            'name_en' => 'Fluttering heart',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/a40.gif'
          },
          {
            'number' => '311',
            'unicode' => 'E329',
            'name' => 'ハートを射とめて',
            'sjis' => '1b244f490f',
            'name_en' => 'Black heart',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/a41.gif'
          },
          {
            'number' => '312',
            'unicode' => 'E32A',
            'name' => 'ハート:青',
            'sjis' => '1b244f4a0f',
            'name_en' => 'Black heart',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image084.gif'
          },
          {
            'number' => '313',
            'unicode' => 'E32B',
            'name' => 'ハート:緑',
            'sjis' => '1b244f4b0f',
            'name_en' => 'Black heart',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image086.gif'
          },
          {
            'number' => '314',
            'unicode' => 'E32C',
            'name' => 'ハート:黄',
            'sjis' => '1b244f4c0f',
            'name_en' => 'Black heart',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image088.gif'
          },
          {
            'number' => '315',
            'unicode' => 'E32D',
            'name' => 'ハート:紫',
            'sjis' => '1b244f4d0f',
            'name_en' => 'Black heart',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image090.gif'
          },
          {
            'number' => '316',
            'unicode' => 'E32E',
            'name' => 'NEW',
            'sjis' => '1b244f4e0f',
            'name_en' => 'Shining new',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/a46.gif'
          },
          {
            'number' => '317',
            'unicode' => 'E32F',
            'name' => '☆',
            'sjis' => '1b244f4f0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image094.gif'
          },
          {
            'number' => '318',
            'unicode' => 'E330',
            'name' => 'ダッシュ',
            'sjis' => '1b244f500f',
            'name_en' => 'Dash (running dash)',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image096.gif'
          },
          {
            'number' => '319',
            'unicode' => 'E331',
            'name' => '飛び散る汗',
            'sjis' => '1b244f510f',
            'name_en' => 'Sweat',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image098.gif'
          },
          {
            'number' => '320',
            'unicode' => 'E332',
            'name' => '○',
            'sjis' => '1b244f520f',
            'name_en' => 'Full moon',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image100.gif'
          },
          {
            'number' => '321',
            'unicode' => 'E333',
            'name' => '×',
            'sjis' => '1b244f530f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image102.gif'
          },
          {
            'number' => '322',
            'unicode' => 'E334',
            'name' => '怒り',
            'sjis' => '1b244f540f',
            'name_en' => 'Angry',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image104.gif'
          },
          {
            'number' => '323',
            'unicode' => 'E335',
            'name' => '☆(点滅)',
            'sjis' => '1b244f550f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/a53.gif'
          },
          {
            'number' => '324',
            'unicode' => 'E336',
            'name' => '動く"?"',
            'sjis' => '1b244f560f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/a54.gif'
          },
          {
            'number' => '325',
            'unicode' => 'E337',
            'name' => '動く"!"',
            'sjis' => '1b244f570f',
            'name_en' => 'Exclamation mark',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/a55.gif'
          },
          {
            'number' => '326',
            'unicode' => 'E338',
            'name' => 'お茶',
            'sjis' => '1b244f580f',
            'name_en' => 'Tea cup',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image112.gif'
          },
          {
            'number' => '327',
            'unicode' => 'E339',
            'name' => 'パン',
            'sjis' => '1b244f590f',
            'name_en' => 'Bread',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image114.gif'
          },
          {
            'number' => '328',
            'unicode' => 'E33A',
            'name' => 'ソフトクリーム',
            'sjis' => '1b244f5a0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image116.gif'
          },
          {
            'number' => '329',
            'unicode' => 'E33B',
            'name' => 'フライドポテト',
            'sjis' => '1b244f5b0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image118.gif'
          },
          {
            'number' => '330',
            'unicode' => 'E33C',
            'name' => '串団子',
            'sjis' => '1b244f5c0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image120.gif'
          },
          {
            'number' => '331',
            'unicode' => 'E33D',
            'name' => 'せんべい',
            'sjis' => '1b244f5d0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image122.gif'
          },
          {
            'number' => '332',
            'unicode' => 'E33E',
            'name' => 'ご飯',
            'sjis' => '1b244f5e0f',
            'name_en' => 'Bowl',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image124.gif'
          },
          {
            'number' => '333',
            'unicode' => 'E33F',
            'name' => 'スパゲッティ',
            'sjis' => '1b244f5f0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image126.gif'
          },
          {
            'number' => '334',
            'unicode' => 'E340',
            'name' => 'ラーメン',
            'sjis' => '1b244f600f',
            'name_en' => 'Bowl',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image128.gif'
          },
          {
            'number' => '335',
            'unicode' => 'E341',
            'name' => 'カレーライス',
            'sjis' => '1b244f610f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image130.gif'
          },
          {
            'number' => '336',
            'unicode' => 'E342',
            'name' => 'おにぎり',
            'sjis' => '1b244f620f',
            'name_en' => 'Rice ball',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image132.gif'
          },
          {
            'number' => '337',
            'unicode' => 'E343',
            'name' => 'おでん',
            'sjis' => '1b244f630f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image134.gif'
          },
          {
            'number' => '338',
            'unicode' => 'E344',
            'name' => '寿司',
            'sjis' => '1b244f640f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image136.gif'
          },
          {
            'number' => '339',
            'unicode' => 'E345',
            'name' => 'りんご',
            'sjis' => '1b244f650f',
            'name_en' => 'Apple',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image138.gif'
          },
          {
            'number' => '340',
            'unicode' => 'E346',
            'name' => 'みかん',
            'sjis' => '1b244f660f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image140.gif'
          },
          {
            'number' => '341',
            'unicode' => 'E347',
            'name' => 'いちご',
            'sjis' => '1b244f670f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image142.gif'
          },
          {
            'number' => '342',
            'unicode' => 'E348',
            'name' => 'すいか',
            'sjis' => '1b244f680f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image144.gif'
          },
          {
            'number' => '343',
            'unicode' => 'E349',
            'name' => 'トマト',
            'sjis' => '1b244f690f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image146.gif'
          },
          {
            'number' => '344',
            'unicode' => 'E34A',
            'name' => 'なす',
            'sjis' => '1b244f6a0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image148.gif'
          },
          {
            'number' => '345',
            'unicode' => 'E34B',
            'name' => 'バースデーケーキ',
            'sjis' => '1b244f6b0f',
            'name_en' => 'Birthday',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/b20.gif'
          },
          {
            'number' => '346',
            'unicode' => 'E34C',
            'name' => '駅弁',
            'sjis' => '1b244f6c0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image152.gif'
          },
          {
            'number' => '347',
            'unicode' => 'E34D',
            'name' => 'ナベ',
            'sjis' => '1b244f6d0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/Emoji_25G_Ver02_02_7799_image154.gif'
          },
          {
            'number' => '348',
            'unicode' => 'E401',
            'name' => 'あせり',
            'sjis' => '1b2450210f',
            'name_en' => 'Cold sweat 2',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image016.gif'
          },
          {
            'number' => '349',
            'unicode' => 'E402',
            'name' => 'ほくそえんでいる',
            'sjis' => '1b2450220f',
            'name_en' => 'Cat 2',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image017.gif'
          },
          {
            'number' => '350',
            'unicode' => 'E403',
            'name' => 'ひたすらごめんなさい',
            'sjis' => '1b2450230f',
            'name_en' => 'Thinking face',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image018.gif'
          },
          {
            'number' => '351',
            'unicode' => 'E404',
            'name' => 'えっへん',
            'sjis' => '1b2450240f',
            'name_en' => 'He he he',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image019.gif'
          },
          {
            'number' => '352',
            'unicode' => 'E405',
            'name' => 'ウィンク',
            'sjis' => '1b2450250f',
            'name_en' => 'Wink',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image020.gif'
          },
          {
            'number' => '353',
            'unicode' => 'E406',
            'name' => 'わさびがきいた',
            'sjis' => '1b2450260f',
            'name_en' => 'Enduring face',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image021.gif'
          },
          {
            'number' => '354',
            'unicode' => 'E407',
            'name' => '目がぐるぐる',
            'sjis' => '1b2450270f',
            'name_en' => 'Sad face',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image022.gif'
          },
          {
            'number' => '355',
            'unicode' => 'E408',
            'name' => '鼻ちょうちん',
            'sjis' => '1b2450280f',
            'name_en' => 'Sleepy (sleep)',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image023.gif'
          },
          {
            'number' => '356',
            'unicode' => 'E409',
            'name' => 'あっかんべー',
            'sjis' => '1b2450290f',
            'name_en' => 'Sticking tongue out',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c09.gif'
          },
          {
            'number' => '357',
            'unicode' => 'E40A',
            'name' => '酔っぱらい',
            'sjis' => '1b24502a0f',
            'name_en' => 'Relief face',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image025.gif'
          },
          {
            'number' => '358',
            'unicode' => 'E40B',
            'name' => 'ゲロゲロ',
            'sjis' => '1b24502b0f',
            'name_en' => 'Very thin',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image026.gif'
          },
          {
            'number' => '359',
            'unicode' => 'E40C',
            'name' => 'マスクをつけた顔',
            'sjis' => '1b24502c0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image027.gif'
          },
          {
            'number' => '360',
            'unicode' => 'E40D',
            'name' => '顔があかくなる',
            'sjis' => '1b24502d0f',
            'name_en' => 'Happy face',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c13.gif'
          },
          {
            'number' => '361',
            'unicode' => 'E40E',
            'name' => 'しらけ顔',
            'sjis' => '1b24502e0f',
            'name_en' => 'Expressionless face',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image029.gif'
          },
          {
            'number' => '362',
            'unicode' => 'E40F',
            'name' => '冷や汗',
            'sjis' => '1b24502f0f',
            'name_en' => 'Cold sweat 2',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image030.gif'
          },
          {
            'number' => '363',
            'unicode' => 'E410',
            'name' => 'びっくり',
            'sjis' => '1b2450300f',
            'name_en' => 'Dizzy',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image034.gif'
          },
          {
            'number' => '364',
            'unicode' => 'E411',
            'name' => '泣き',
            'sjis' => '1b2450310f',
            'name_en' => 'Crying',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image035.gif'
          },
          {
            'number' => '365',
            'unicode' => 'E412',
            'name' => '泣いたり笑ったり',
            'sjis' => '1b2450320f',
            'name_en' => 'Happy face',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c18.gif'
          },
          {
            'number' => '366',
            'unicode' => 'E413',
            'name' => '可愛く泣いている人',
            'sjis' => '1b2450330f',
            'name_en' => 'Tear',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image050.gif'
          },
          {
            'number' => '367',
            'unicode' => 'E414',
            'name' => 'にこにこ',
            'sjis' => '1b2450340f',
            'name_en' => 'Happy face',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image051.gif'
          },
          {
            'number' => '368',
            'unicode' => 'E415',
            'name' => 'あははと笑う',
            'sjis' => '1b2450350f',
            'name_en' => 'Happy face',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image052.gif'
          },
          {
            'number' => '369',
            'unicode' => 'E416',
            'name' => 'めちゃめちゃ怒っている',
            'sjis' => '1b2450360f',
            'name_en' => 'Pouting face',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image053.gif'
          },
          {
            'number' => '370',
            'unicode' => 'E417',
            'name' => 'KISS:動く口',
            'sjis' => '1b2450370f',
            'name_en' => 'Heart shaped eyes',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c23.gif'
          },
          {
            'number' => '371',
            'unicode' => 'E418',
            'name' => '投げKISS',
            'sjis' => '1b2450380f',
            'name_en' => 'Heart shaped eyes',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image055.gif'
          },
          {
            'number' => '372',
            'unicode' => 'E419',
            'name' => '目',
            'sjis' => '1b2450390f',
            'name_en' => 'Eyes',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image056.gif'
          },
          {
            'number' => '373',
            'unicode' => 'E41A',
            'name' => '鼻',
            'sjis' => '1b24503a0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image057.gif'
          },
          {
            'number' => '374',
            'unicode' => 'E41B',
            'name' => '耳',
            'sjis' => '1b24503b0f',
            'name_en' => 'Ear',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image058.gif'
          },
          {
            'number' => '375',
            'unicode' => 'E41C',
            'name' => '口',
            'sjis' => '1b24503c0f',
            'name_en' => 'Kiss',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/c28.gif'
          },
          {
            'number' => '376',
            'unicode' => 'E41D',
            'name' => 'ごめんなさい',
            'sjis' => '1b24503d0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image060.gif'
          },
          {
            'number' => '377',
            'unicode' => 'E41E',
            'name' => 'バイバイ',
            'sjis' => '1b24503e0f',
            'name_en' => 'Hand (paper)',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/d02.gif'
          },
          {
            'number' => '378',
            'unicode' => 'E41F',
            'name' => '拍手',
            'sjis' => '1b24503f0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/d03.gif'
          },
          {
            'number' => '379',
            'unicode' => 'E420',
            'name' => 'OK',
            'sjis' => '1b2450400f',
            'name_en' => 'Accept',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image079.gif'
          },
          {
            'number' => '380',
            'unicode' => 'E421',
            'name' => 'Booing',
            'sjis' => '1b2450410f',
            'name_en' => 'Bad (downward arrow)',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image080.gif'
          },
          {
            'number' => '381',
            'unicode' => 'E422',
            'name' => 'おっは〜',
            'sjis' => '1b2450420f',
            'name_en' => 'Hand (paper)',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/d06.gif'
          },
          {
            'number' => '382',
            'unicode' => 'E423',
            'name' => '×',
            'sjis' => '1b2450430f',
            'name_en' => 'NG (No good)',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/d07.gif'
          },
          {
            'number' => '383',
            'unicode' => 'E424',
            'name' => '○',
            'sjis' => '1b2450440f',
            'name_en' => 'Accept',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/d08.gif'
          },
          {
            'number' => '384',
            'unicode' => 'E425',
            'name' => '手をつないでいる',
            'sjis' => '1b2450450f',
            'name_en' => 'Fluttering heart',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image084.gif'
          },
          {
            'number' => '385',
            'unicode' => 'E426',
            'name' => '土下座',
            'sjis' => '1b2450460f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/d10.gif'
          },
          {
            'number' => '386',
            'unicode' => 'E427',
            'name' => 'バンザイ',
            'sjis' => '1b2450470f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/d11.gif'
          },
          {
            'number' => '387',
            'unicode' => 'E428',
            'name' => '人と人が歩いている',
            'sjis' => '1b2450480f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/d12.gif'
          },
          {
            'number' => '388',
            'unicode' => 'E429',
            'name' => 'ラインダンス',
            'sjis' => '1b2450490f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/d13.gif'
          },
          {
            'number' => '389',
            'unicode' => 'E42A',
            'name' => 'バスケットボール',
            'sjis' => '1b24504a0f',
            'name_en' => 'Basketball',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image089.gif'
          },
          {
            'number' => '390',
            'unicode' => 'E42B',
            'name' => 'フットボール',
            'sjis' => '1b24504b0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image090.gif'
          },
          {
            'number' => '391',
            'unicode' => 'E42C',
            'name' => 'ビリヤード',
            'sjis' => '1b24504c0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image091.gif'
          },
          {
            'number' => '392',
            'unicode' => 'E42D',
            'name' => '水泳',
            'sjis' => '1b24504d0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/e04.gif'
          },
          {
            'number' => '393',
            'unicode' => 'E42E',
            'name' => 'RV',
            'sjis' => '1b24504e0f',
            'name_en' => 'Car (RV)',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image093.gif'
          },
          {
            'number' => '394',
            'unicode' => 'E42F',
            'name' => 'トラック',
            'sjis' => '1b24504f0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image094.gif'
          },
          {
            'number' => '395',
            'unicode' => 'E430',
            'name' => '消防車',
            'sjis' => '1b2450500f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image111.gif'
          },
          {
            'number' => '396',
            'unicode' => 'E431',
            'name' => '救急車',
            'sjis' => '1b2450510f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image112.gif'
          },
          {
            'number' => '397',
            'unicode' => 'E432',
            'name' => 'パトカー',
            'sjis' => '1b2450520f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image113.gif'
          },
          {
            'number' => '398',
            'unicode' => 'E433',
            'name' => 'ジェットコースター',
            'sjis' => '1b2450530f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/f06.gif'
          },
          {
            'number' => '399',
            'unicode' => 'E434',
            'name' => '地下鉄',
            'sjis' => '1b2450540f',
            'name_en' => 'Subway',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image115.gif'
          },
          {
            'number' => '400',
            'unicode' => 'E435',
            'name' => '新幹線(700系)',
            'sjis' => '1b2450550f',
            'name_en' => 'Bullet train',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image116.gif'
          },
          {
            'number' => '401',
            'unicode' => 'E436',
            'name' => '門松',
            'sjis' => '1b2450560f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image117.gif'
          },
          {
            'number' => '402',
            'unicode' => 'E437',
            'name' => 'チョコ',
            'sjis' => '1b2450570f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/g02.gif'
          },
          {
            'number' => '403',
            'unicode' => 'E438',
            'name' => 'お雛様',
            'sjis' => '1b2450580f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image119.gif'
          },
          {
            'number' => '404',
            'unicode' => 'E439',
            'name' => '卒業式',
            'sjis' => '1b2450590f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image120.gif'
          },
          {
            'number' => '405',
            'unicode' => 'E43A',
            'name' => 'ランドセル',
            'sjis' => '1b24505a0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image121.gif'
          },
          {
            'number' => '406',
            'unicode' => 'E43B',
            'name' => '鯉のぼり',
            'sjis' => '1b24505b0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image122.gif'
          },
          {
            'number' => '407',
            'unicode' => 'E43C',
            'name' => 'とじかさ',
            'sjis' => '1b24505c0f',
            'name_en' => 'Drizzle',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image123.gif'
          },
          {
            'number' => '408',
            'unicode' => 'E43D',
            'name' => '結婚式',
            'sjis' => '1b24505d0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image124.gif'
          },
          {
            'number' => '409',
            'unicode' => 'E43E',
            'name' => '波がザーン',
            'sjis' => '1b24505e0f',
            'name_en' => 'Wave',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/g09.gif'
          },
          {
            'number' => '410',
            'unicode' => 'E43F',
            'name' => 'かき氷',
            'sjis' => '1b24505f0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image126.gif'
          },
          {
            'number' => '411',
            'unicode' => 'E440',
            'name' => '線香花火',
            'sjis' => '1b2450600f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/g11.gif'
          },
          {
            'number' => '412',
            'unicode' => 'E441',
            'name' => '貝',
            'sjis' => '1b2450610f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image140.gif'
          },
          {
            'number' => '413',
            'unicode' => 'E442',
            'name' => '風鈴',
            'sjis' => '1b2450620f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/g13.gif'
          },
          {
            'number' => '414',
            'unicode' => 'E443',
            'name' => '台風',
            'sjis' => '1b2450630f',
            'name_en' => 'Typhoon',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image142.gif'
          },
          {
            'number' => '415',
            'unicode' => 'E444',
            'name' => '稲穂',
            'sjis' => '1b2450640f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image143.gif'
          },
          {
            'number' => '416',
            'unicode' => 'E445',
            'name' => 'ハロウィン',
            'sjis' => '1b2450650f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image144.gif'
          },
          {
            'number' => '417',
            'unicode' => 'E446',
            'name' => 'お月見',
            'sjis' => '1b2450660f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image145.gif'
          },
          {
            'number' => '418',
            'unicode' => 'E447',
            'name' => '風がビュー',
            'sjis' => '1b2450670f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/g18.gif'
          },
          {
            'number' => '419',
            'unicode' => 'E448',
            'name' => 'サンタクロース',
            'sjis' => '1b2450680f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image147.gif'
          },
          {
            'number' => '420',
            'unicode' => 'E449',
            'name' => '朝日',
            'sjis' => '1b2450690f',
            'name_en' => 'Fine',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image148.gif'
          },
          {
            'number' => '421',
            'unicode' => 'E44A',
            'name' => '夕日',
            'sjis' => '1b24506a0f',
            'name_en' => 'Fine',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image149.gif'
          },
          {
            'number' => '422',
            'unicode' => 'E44B',
            'name' => '流れ星',
            'sjis' => '1b24506b0f',
            'name_en' => 'Night',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/g22.gif'
          },
          {
            'number' => '423',
            'unicode' => 'E44C',
            'name' => '虹',
            'sjis' => '1b24506c0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/image152.gif'
          },
          {
            'number' => '424',
            'unicode' => 'E501',
            'name' => 'ラブホテル',
            'sjis' => '1b2451210f',
            'name_en' => 'Hotel',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image016.gif'
          },
          {
            'number' => '425',
            'unicode' => 'E502',
            'name' => 'アート',
            'sjis' => '1b2451220f',
            'name_en' => 'Art',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image017.gif'
          },
          {
            'number' => '426',
            'unicode' => 'E503',
            'name' => '演劇',
            'sjis' => '1b2451230f',
            'name_en' => 'Drama',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image018.gif'
          },
          {
            'number' => '427',
            'unicode' => 'E504',
            'name' => 'デパート',
            'sjis' => '1b2451240f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image019.gif'
          },
          {
            'number' => '428',
            'unicode' => 'E505',
            'name' => 'お城(和)',
            'sjis' => '1b2451250f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image020.gif'
          },
          {
            'number' => '429',
            'unicode' => 'E506',
            'name' => 'お城(洋)',
            'sjis' => '1b2451260f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image021.gif'
          },
          {
            'number' => '430',
            'unicode' => 'E507',
            'name' => '映画館',
            'sjis' => '1b2451270f',
            'name_en' => 'Movie',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image022.gif'
          },
          {
            'number' => '431',
            'unicode' => 'E508',
            'name' => '工場',
            'sjis' => '1b2451280f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image023.gif'
          },
          {
            'number' => '432',
            'unicode' => 'E509',
            'name' => '東京タワー',
            'sjis' => '1b2451290f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image024.gif'
          },
          {
            'number' => '433',
            'unicode' => 'E50A',
            'name' => '109',
            'sjis' => '1b24512a0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image025.gif'
          },
          {
            'number' => '434',
            'unicode' => 'E50B',
            'name' => '日本',
            'sjis' => '1b24512b0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image026.gif'
          },
          {
            'number' => '435',
            'unicode' => 'E50C',
            'name' => 'アメリカ',
            'sjis' => '1b24512c0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image027.gif'
          },
          {
            'number' => '436',
            'unicode' => 'E50D',
            'name' => 'フランス',
            'sjis' => '1b24512d0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image028.gif'
          },
          {
            'number' => '437',
            'unicode' => 'E50E',
            'name' => 'ドイツ',
            'sjis' => '1b24512e0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image029.gif'
          },
          {
            'number' => '438',
            'unicode' => 'E50F',
            'name' => 'イタリア',
            'sjis' => '1b24512f0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image030.gif'
          },
          {
            'number' => '439',
            'unicode' => 'E510',
            'name' => 'イギリス',
            'sjis' => '1b2451300f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image047.gif'
          },
          {
            'number' => '440',
            'unicode' => 'E511',
            'name' => 'スペイン',
            'sjis' => '1b2451310f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image048.gif'
          },
          {
            'number' => '441',
            'unicode' => 'E512',
            'name' => 'ロシア',
            'sjis' => '1b2451320f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image049.gif'
          },
          {
            'number' => '442',
            'unicode' => 'E513',
            'name' => '中国',
            'sjis' => '1b2451330f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image050.gif'
          },
          {
            'number' => '443',
            'unicode' => 'E514',
            'name' => '韓国',
            'sjis' => '1b2451340f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image051.gif'
          },
          {
            'number' => '444',
            'unicode' => 'E515',
            'name' => '白人',
            'sjis' => '1b2451350f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image052.gif'
          },
          {
            'number' => '445',
            'unicode' => 'E516',
            'name' => '中国人',
            'sjis' => '1b2451360f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image053.gif'
          },
          {
            'number' => '446',
            'unicode' => 'E517',
            'name' => 'インド人',
            'sjis' => '1b2451370f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image054.gif'
          },
          {
            'number' => '447',
            'unicode' => 'E518',
            'name' => 'おじいちゃん',
            'sjis' => '1b2451380f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image055.gif'
          },
          {
            'number' => '448',
            'unicode' => 'E519',
            'name' => 'おばあちゃん',
            'sjis' => '1b2451390f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image056.gif'
          },
          {
            'number' => '449',
            'unicode' => 'E51A',
            'name' => 'あかちゃん',
            'sjis' => '1b24513a0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image057.gif'
          },
          {
            'number' => '450',
            'unicode' => 'E51B',
            'name' => '安全第一',
            'sjis' => '1b24513b0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image058.gif'
          },
          {
            'number' => '451',
            'unicode' => 'E51C',
            'name' => 'お姫さま',
            'sjis' => '1b24513c0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image059.gif'
          },
          {
            'number' => '452',
            'unicode' => 'E51D',
            'name' => '自由の女神',
            'sjis' => '1b24513d0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image060.gif'
          },
          {
            'number' => '453',
            'unicode' => 'E51E',
            'name' => '衛兵',
            'sjis' => '1b24513e0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image061.gif'
          },
          {
            'number' => '454',
            'unicode' => 'E51F',
            'name' => 'フラメンコ',
            'sjis' => '1b24513f0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/i21.gif'
          },
          {
            'number' => '455',
            'unicode' => 'E520',
            'name' => 'イルカ',
            'sjis' => '1b2451400f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image074.gif'
          },
          {
            'number' => '456',
            'unicode' => 'E521',
            'name' => 'とり',
            'sjis' => '1b2451410f',
            'name_en' => 'Baby chick',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image075.gif'
          },
          {
            'number' => '457',
            'unicode' => 'E522',
            'name' => '熱帯魚',
            'sjis' => '1b2451420f',
            'name_en' => 'Fish',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image076.gif'
          },
          {
            'number' => '458',
            'unicode' => 'E523',
            'name' => 'ひよこ',
            'sjis' => '1b2451430f',
            'name_en' => 'Baby chick',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image077.gif'
          },
          {
            'number' => '459',
            'unicode' => 'E524',
            'name' => 'ハムスター',
            'sjis' => '1b2451440f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image078.gif'
          },
          {
            'number' => '460',
            'unicode' => 'E525',
            'name' => 'けむし',
            'sjis' => '1b2451450f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image079.gif'
          },
          {
            'number' => '461',
            'unicode' => 'E526',
            'name' => 'ぞう',
            'sjis' => '1b2451460f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image080.gif'
          },
          {
            'number' => '462',
            'unicode' => 'E527',
            'name' => 'こあら',
            'sjis' => '1b2451470f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image081.gif'
          },
          {
            'number' => '463',
            'unicode' => 'E528',
            'name' => 'チンパジー',
            'sjis' => '1b2451480f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image082.gif'
          },
          {
            'number' => '464',
            'unicode' => 'E529',
            'name' => 'ひつじ',
            'sjis' => '1b2451490f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image083.gif'
          },
          {
            'number' => '465',
            'unicode' => 'E52A',
            'name' => 'おおかみ',
            'sjis' => '1b24514a0f',
            'name_en' => 'Dog',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image084.gif'
          },
          {
            'number' => '466',
            'unicode' => 'E52B',
            'name' => 'うし',
            'sjis' => '1b24514b0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image100.gif'
          },
          {
            'number' => '467',
            'unicode' => 'E52C',
            'name' => 'うさぎ',
            'sjis' => '1b24514c0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image101.gif'
          },
          {
            'number' => '468',
            'unicode' => 'E52D',
            'name' => 'へび',
            'sjis' => '1b24514d0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image102.gif'
          },
          {
            'number' => '469',
            'unicode' => 'E52E',
            'name' => 'にわとり',
            'sjis' => '1b24514e0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image103.gif'
          },
          {
            'number' => '470',
            'unicode' => 'E52F',
            'name' => 'いのしし',
            'sjis' => '1b24514f0f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image104.gif'
          },
          {
            'number' => '471',
            'unicode' => 'E530',
            'name' => 'らくだ',
            'sjis' => '1b2451500f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image105.gif'
          },
          {
            'number' => '472',
            'unicode' => 'E531',
            'name' => 'かえる',
            'sjis' => '1b2451510f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image106.gif'
          },
          {
            'number' => '473',
            'unicode' => 'E532',
            'name' => 'A型',
            'sjis' => '1b2451520f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image107.gif'
          },
          {
            'number' => '474',
            'unicode' => 'E533',
            'name' => 'B型',
            'sjis' => '1b2451530f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image108.gif'
          },
          {
            'number' => '475',
            'unicode' => 'E534',
            'name' => 'AB型',
            'sjis' => '1b2451540f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image109.gif'
          },
          {
            'number' => '476',
            'unicode' => 'E535',
            'name' => 'O型',
            'sjis' => '1b2451550f',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image110.gif'
          },
          {
            'number' => '477',
            'unicode' => 'E536',
            'name' => '足あと',
            'sjis' => '1b2451560f',
            'name_en' => 'Foot',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image111.gif'
          },
          {
            'number' => '478',
            'unicode' => 'E537',
            'name' => 'TM',
            'sjis' => '1b2451570f',
            'name_en' => 'Trademark',
            'image' => 'http://developers.softbankmobile.co.jp/dp/tool_dl/web/images/code5_31525_image112.gif'
          }
        ]
